.. pointpats documentation master file, created by
   sphinx-quickstart on Mon Nov 12 16:37:22 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Point Pattern Analysis (pointpats)
========================================

pointpats is an open-source python library for the statistical analysis of planar point patterns.
It is a subpackage of `PySAL`_ (Python Spatial Analysis Library) and is under active development
for the inclusion of many newly proposed analytics for point patterns.


.. raw:: html

    <div class="container-fluid">
      <div class="row equal-height">
        <div class="col-sm-1 col-xs-hidden">
        </div>
        <div class="col-md-3 col-xs-12">
            <a href="https://nbviewer.org/github/pysal/pointpats/blob/main/notebooks/process.ipynb" class="thumbnail">
                <img src="_static/images/point_process.png" class="img-responsive center-block">
                <div class="caption text-center">
                <h6>Simulating point processes</h6>
                </div>
            </a>
        </div>
        <div class="col-sm-3 col-xs-12">
            <a href="https://nbviewer.org/github/pysal/pointpats/blob/main/notebooks/Quadrat_statistics.ipynb" class="thumbnail">
                <img src="_static/images/quadrat.png" class="img-responsive center-block">
                <div class="caption text-center">
                <h6>Quadrat based statistics for point pattern analysis</h6>
                </div>
            </a>
        </div>
        <div class="col-sm-3 col-xs-12">
            <a href="https://github.com/pysal/pointpats/blob/main/notebooks/distance_statistics-numpy-oriented.ipynb" class="thumbnail">
                <img src="_static/images/G_sim_envelope.png"
                class="img-responsive center-block">
                <div class="caption text-center">
                <h6>Distance based statistics for point pattern analysis
                </h6>
                </div>
            </a>
        </div>
        <div class="col-sm-2 col-xs-hidden">
        </div>
      </div>
    </div>


.. toctree::
   :hidden:
   :maxdepth: 3
   :caption: Contents:

   Installation <installation>
   API <api>
   References <references>


.. _PySAL: https://github.com/pysal/pysal
